@@ -109,3 +109,18 @@ class UnknownRelationalFieldError(BuilderError):
         super().__init__(
             f'Field: "{field}" either does not exist or is not a relational field on the {model} model'
         )
+
+
+class GeneratorError(PrismaError):
+    pass
+
+
+class UnsupportedListTypeError(GeneratorError):
+    type: str
+
+    def __init__(self, typ: str) -> None:
+        super().__init__(
+            f'Cannot use {typ} as a list yet; Please create a '
+            'feature request at https://github.com/RobertCraigie/prisma-client-py/issues/new'
+        )
+        self.type = typ
